@@ -1,13 +1,13 @@
 import os
-from cStringIO import StringIO
 import tarfile
 
 import numpy as np
 
 from . import get_data_home
-from tools import download_with_progress_bar
-DATA_URL = ("http://www.astro.washington.edu/users/bsesar/"
-            "S82_RRLyr/RRLyr_ugriz_templates.tar.gz")
+from .tools import download_with_progress_bar
+
+DATA_URL = ("https://github.com/astroML/astroML-data/raw/main/datasets/"
+            "RRLyr_ugriz_templates.tar.gz")
 
 
 def fetch_rrlyrae_templates(data_home=None, download_if_missing=True):
@@ -19,7 +19,7 @@ def fetch_rrlyrae_templates(data_home=None, download_if_missing=True):
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : optional, default=True
         If False, raise a IOError if the data is not locally available
@@ -31,8 +31,6 @@ def fetch_rrlyrae_templates(data_home=None, download_if_missing=True):
         record array containing the templates
     """
     data_home = get_data_home(data_home)
-    if not os.path.exists(data_home):
-        os.makedirs(data_home)
 
     data_file = os.path.join(data_home, os.path.basename(DATA_URL))
 
@@ -46,6 +44,5 @@ def fetch_rrlyrae_templates(data_home=None, download_if_missing=True):
 
     data = tarfile.open(data_file)
 
-    return dict([(name.strip('.dat'),
-                  np.loadtxt(data.extractfile(name)))
-                 for name in data.getnames()])
+    return {name.strip('.dat'):
+            np.loadtxt(data.extractfile(name)) for name in data.getnames()}
